@@ -606,6 +606,19 @@ static NvBool nv_dma_is_map_resource_implemented
 #if defined(NV_DMA_MAP_RESOURCE_PRESENT)
     const struct dma_map_ops *ops = get_dma_ops(&nvl->dev->dev);
 
+    if (ops == NULL)
+    {
+        /* On pre-5.0 kernels, if dma_map_resource() is present, then we
+         * assume that ops != NULL.  With direct_dma handling swiotlb on 5.0+
+         * kernels, ops == NULL.
+         */
+#if defined(NV_DMA_IS_DIRECT_PRESENT)
+        return NV_TRUE;
+#else
+        return NV_FALSE;
+#endif
+    }
+
     return (ops && ops->map_resource);
 #else
     return NV_FALSE;
