@@ -185,7 +185,7 @@ nvidia_vma_access(
 }
 #endif
 
-struct vm_operations_struct nv_vm_ops = {
+static struct vm_operations_struct nv_vm_ops = {
     .open   = nvidia_vma_open,
     .close  = nvidia_vma_release,
 #if defined(NV_VM_OPERATIONS_STRUCT_HAS_ACCESS)
